@@ -24,9 +24,8 @@ class EzFlask:
         @self.app.route('/<path>')
         def _get(path):
             return _get_html(escape(path))
+        
+        self.run()
 
     def run(self):
         self.app.run(host='0.0.0.0', port=8080)
-
-
-EzFlask().run()
